module.exports = defineTest({
	description: 'Template literals can be simplified when used in conditionals'
});
